pub fn transact_erc20evm<EVM>(
evm: &mut EVM,
) -> Result<(ExecutionResult<HaltReason>, EvmState), EVMError<ContextTrDbError<EVM::Context>, InvalidTransaction>>Expand description
Executes a transaction using ERC20 tokens for gas payment. Returns the execution result and the finalized state changes. This function does not commit the state to the database.